@@ -292,6 +292,7 @@ if(defined $opt_realtime) {
 }
 if(defined $opt_undirected) {
     $option_hash{"undirected"} = $opt_undirected;
+    $option_hash{"realtime"} = 1; 
 }
 if(defined $opt_config) {
     $option_hash{"config"} = $opt_config;
@@ -489,7 +490,8 @@ sub showHelp() {
 
     print "--config FILE            Configuration file\n\n";
     
-    print "--realtime               This option will not create a database of the\n";
+    print "--realtime
+               This option will not create a database of the\n";
     print "                         path information for all of concepts but just\n"; 
     print "                         obtain the information for the input concept\n\n";
     print "--forcerun               This option will bypass any command \n";
@@ -516,7 +518,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findShortestPath.pl,v 1.25 2011/08/29 16:37:03 btmcinnes Exp $';
+    print '$Id: findShortestPath.pl,v 1.26 2014/06/27 00:18:32 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
