@@ -159,13 +159,6 @@ if( !(defined $opt_infile) and (scalar(@ARGV) < 2) ) {
     exit;
 }
 
-my $database = "umls";
-if(defined $opt_database) { $database = $opt_database; }
-my $hostname = "localhost";
-if(defined $opt_hostname) { $hostname = $opt_hostname; }
-my $socket   = "/tmp/mysql.sock";
-if(defined $opt_socket)   { $socket   = $opt_socket;   }
-
 my $umls = "";
 my %option_hash = ();
 
@@ -179,19 +172,19 @@ if(defined $opt_username) {
     $option_hash{"username"} = $opt_username;
 }
 if(defined $opt_driver) {
-    $option_hash{"driver"}   = "mysql";
+    $option_hash{"driver"}   = $opt_driver;
 }
 if(defined $opt_database) {
-    $option_hash{"database"} = $database;
+    $option_hash{"database"} = $opt_database;
 }
 if(defined $opt_password) {
     $option_hash{"password"} = $opt_password;
 }
 if(defined $opt_hostname) {
-    $option_hash{"hostname"} = $hostname;
+    $option_hash{"hostname"} = $opt_hostname;
 }
 if(defined $opt_socket) {
-    $option_hash{"socket"}   = $socket;
+    $option_hash{"socket"}   = $opt_socket;
 }
 
 $option_hash{"t"} = 1;
@@ -275,7 +268,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getSemanticRelation.pl,v 1.2 2011/04/26 12:19:28 btmcinnes Exp $';
+    print '$Id: getSemanticRelation.pl,v 1.3 2011/08/29 16:37:03 btmcinnes Exp $';
     print "\nCopyright (c) 2011, Ted Pedersen & Bridget McInnes\n";
 }
 
